// * * * * * * * * * * * * * Properties fields * * * * * * * * * * * * * * * //

Info<< "Reading solutionProperties\n" << endl;

IOdictionary solutionProperties
(
    IOobject
    (
        "solutionProperties",
        runTime.constant(),
        mesh,
        IOobject::MUST_READ_IF_MODIFIED,
        IOobject::NO_WRITE
    )
);

//IOdictionary::toc() : table of contents
const wordList soluteNameList(solutionProperties.toc());

PtrList<solute> soluteList(soluteNameList.size());

//for divSchemes later on
//multivariateSurfaceInterpolationScheme<scalar>::fieldTable soluteFields;

forAll(soluteNameList, i)
{
    const word& soluteName = soluteNameList[i];
    const dictionary& soluteDict = solutionProperties.subDict(soluteName);

    soluteList.set
    (
        i,
        new solute
        (
            soluteDict,
            mesh
        )
    );

//    soluteFields.add(soluteList[i]);
}


//    Info<< "\nDiffusion = " << soluteList[0].name() << endl;

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

Info<< "Reading transportProperties\n" << endl;

IOdictionary transportProperties
(
  IOobject
  (
    "transportProperties",
    runTime.constant(),
    mesh,
    IOobject::MUST_READ_IF_MODIFIED,
    IOobject::NO_WRITE
  )
);

dimensionedScalar nu
(
  transportProperties.lookup("nu")
);

// * * * * * * * * * * * * * Reading fields * * * * * * * * * * * * * * * * //
Info<< "Reading field p\n" << endl;
volScalarField p
(
  IOobject
  (
    "p",
    runTime.timeName(),
    mesh,
    IOobject::MUST_READ,
    IOobject::AUTO_WRITE
  ),
  mesh
);


Info<< "Reading field U\n" << endl;
volVectorField U
(
  IOobject
  (
    "U",
    runTime.timeName(),
    mesh,
    IOobject::MUST_READ,
    IOobject::AUTO_WRITE
  ),
  mesh
);

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#include "createPhi.H"

label pRefCell = 0;
scalar pRefValue = 0.0;
setRefCell(p, mesh.solutionDict().subDict("PISO"), pRefCell, pRefValue);

//***************************************************************************//
