/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2011 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::solute

Description
    Single incompressible solution solute.
    Used as part of the multiComponentSolution to store solute data.

SourceFiles
    solute.C

Author
    Rudolf Hellmuth (rudolf.hellmuth@gmail.com)

\*---------------------------------------------------------------------------*/

#include "volFields.H"
#include "dictionaryEntry.H"

#ifndef SOLUTE_H
#define SOLUTE_H

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

/*---------------------------------------------------------------------------*\
                           Class solute Declaration
\*---------------------------------------------------------------------------*/

class solute
:
    public volScalarField
{
    // Private data

        word name_;
        dictionary soluteDict_;

        dimensionedScalar D_;
        word diffusionModel_;

public:

    // Constructors

        //- Construct from components
        solute
        (
            const dictionary& soluteDict,
            const fvMesh& mesh
        );

        //- Return clone
        autoPtr<solute> clone() const;

        //- Return a pointer to a new solute created on freestore
        //  from Istream
        class iNew
        {
            const fvMesh& mesh_;

        public:

            iNew
            (
                const fvMesh& mesh
            )
            :
                mesh_(mesh)
            {}
            autoPtr<solute> operator()(Istream& is) const
            {
                dictionaryEntry ent(dictionary::null, is);
                return autoPtr<solute>(new solute(ent, mesh_));
            }
        };

    // Destructor


    // Member Functions

        const word& name() const
        {
            return name_;
        }

        const word& keyword() const
        {
            return name();
        }

        //- Return const-access to solute diffusion coefficient
        const dimensionedScalar& D() const
        {
            return D_;
        }

        //- Return const-access to solute diffusion model
        const word& diffusionModel() const
        {
            return diffusionModel_;
        }

        //- Return const-access to solute molar mass
//        const dimensionedScalar& molarMass() const
//        {
//            return molarMass_;
//        }

        //- Read base transportProperties dictionary
        bool read(const dictionary& soluteDict);
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
